@@ -31,9 +31,9 @@
 
 #include <KAction>
 #include <KActionCollection>
-#include <KDebug>
 #include <KEncodingFileDialog>
 #include <KFind>
+#include <KFileDialog>
 #include <KFindDialog>
 #include <KIcon>
 #include <KLocale>
@@ -50,9 +50,8 @@
 #include <QTextStream>
 #include <QVBoxLayout>
 #include <QWidget>
-#include <QtDBus/QtDBus>
-#include <QtGui/QPrintDialog>
-#include <QtGui/QPrinter>
+#include <QPrintDialog>
+#include <QPrinter>
 #include <kio/netaccess.h>
 #include <kio/renamedialog.h>
 
@@ -490,7 +489,7 @@ void KgpgEditor::slotFilePreDec()
     oldname.prepend(url.directory(KUrl::AppendTrailingSlash));
 
     QPointer<KDialog> popn = new KDialog(this);
-    popn->setCaption(  i18n("Decrypt File To") );
+    popn->setWindowTitle(i18n("Decrypt File To"));
     popn->setButtons( KDialog::Ok | KDialog::Cancel );
     popn->setDefaultButton( KDialog::Ok );
     popn->setModal( true );
@@ -762,5 +761,3 @@ void KgpgEditor::newText()
 	setCaption(i18n("Untitled"), false);
 	slotResetEncoding(false);
 }
-
-#include "kgpgeditor.moc"
